/*
** This file is part of BrandyTerminal, a Mac OS X container for Brandy.
** Copyright (C) 2002, 2004 Crispian Daniels
**
** BrandyTerminal is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2, or (at your option)
** any later version.
**
** BrandyTerminal is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with BrandyTerminal; see the file COPYING.  If not, write to
** the Free Software Foundation, 59 Temple Place - Suite 330,
** Boston, MA 02111-1307, USA.
**
**
**	This file contains the interface for the BackChannel class.
**
**	The btermconio addition to Brandy uses the back channel to
**	enquire after the cursor position.
*/

#import <Cocoa/Cocoa.h>

#import <semaphore.h>

@class MyDocument;

@interface BackChannel : NSObject {
    NSString *deviceName;
    sem_t *requestSemaphore;
    sem_t *resultSemaphore;
    int sharedMemoryFD;
    int *sharedMemory;
	int screenMemoryFD;
	struct btjlScreenBufferStruct *screenMemory;
}
+ (BackChannel *)channelForDeviceName:(NSString *)name;
- (void)close;
- (void)poll:(id)handler document:(MyDocument *)document;
- (int)getInt:(int)index;
- (void)setInt:(int)index value:(int)value;

- (BOOL)openScreen;
- (void)closeScreen;
- (struct btjlScreenBufferStruct *)screen;
@end

@interface NSObject (BackChannelHandler)
- (void)backChannelRequest:(BackChannel *)channel document:(MyDocument *)document;
- (void)screenUpdateRequest:(BackChannel *)channel document:(MyDocument *)document;
@end
