/*
** This file is part of BrandyTerminal, a Mac OS X container for Brandy.
** Copyright (C) 2002 Crispian Daniels
**
** BrandyTerminal is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2, or (at your option)
** any later version.
**
** BrandyTerminal is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with BrandyTerminal; see the file COPYING.  If not, write to
** the Free Software Foundation, 59 Temple Place - Suite 330,
** Boston, MA 02111-1307, USA.
**
**
**	This file contains main(), the application's entry point.
**
**	Before the usual NSApplicationMain() call, main() installs
**	an application delegate and a signal handler.
**
**	The signal handler is used to detect the termination of
**	child processes - which if all goes well are instances of
**	the Brandy Basic V interpreter.
*/

#import <Cocoa/Cocoa.h>
#import <signal.h>
#import "AppDelegate.h"
#import "Child.h"

static void initSignalHandlers();

int main(int argc, const char *argv[])
{
    NSAutoreleasePool *pool = [[NSAutoreleasePool alloc] init];
    AppDelegate *delegate = [[AppDelegate alloc] init];

    [Child initChildList];
    initSignalHandlers();
    [[NSApplication sharedApplication] setDelegate:delegate];

    [pool release];

    return NSApplicationMain(argc, argv);
}

void childSigHandler(int signo)
{
    [Child handleSIGCHLD];
}

void initSignalHandlers()
{
    struct sigaction action;

    action.sa_handler = childSigHandler;
    action.sa_mask = 0;
    action.sa_flags = SA_NOCLDSTOP;

    sigaction(SIGCHLD, &action, NULL);
}
